@@ -12,7 +12,18 @@ use Runner qw(get_path);
 my $greple_path = get_path('greple', 'App::Greple') or die Dumper \%INC;
 
 sub has_jq {
-    !! grep { -x "$_/jq" } split /:+/, $ENV{PATH};
+    my @path = grep { -x } map { "$_/jq" } split /:+/, $ENV{PATH} or do {
+	warn "jq command is not available.\n";
+	return 0;
+    };
+    my $version = `$path[0] --version`;
+    if ($? == 0) {
+	warn "$version";
+	return 1;
+    } else {
+	warn "jq command execution error.\n";
+	return 0;
+    }
 }
 
 my $module = has_jq() ? 'jq' : 'jq::set(noif)';
